@@ -211,6 +211,7 @@ class Salesforce(SalureConnect):
             'Dorcas_Exchange_Rates__c': 'incremental',
             'Dorcas_Report__c': 'incremental',
             'General_Ledger_Account__c': 'incremental',
+            'Lead': 'incremental',
             'npe03__Recurring_Donation__c': 'incremental',
             'npsp__General_Accounting_Unit__c': 'incremental',
             'Opportunity': 'incremental',
@@ -317,4 +318,4 @@ class Salesforce(SalureConnect):
             df = df.astype(str)
             df.to_feather(f'{data_dir}cache/{filename}.ftr', compression='lz4')
 
-            return df
+        return df
